/*!
  \file AlignmentMuonRenderPlugin
  \brief Display Plugin for DQM AlignmentMuon
  \author J. Fernandez - Univ. Oviedo <Javier.Fernandez@cern.ch>
  $Revision: 1.2 $
  $Date: 2009/01/06 20:18:27 $
*/

#include "TStyle.h"
#include "TCanvas.h"
#include "TPaletteAxis.h"
#include <cassert>
#include "TList.h"

#include "DQM/RenderPlugins/src/AlignmentMuonRenderPlugin.h"
#include "DQM/RenderPlugins/src/utils.h"



AlignmentMuonRenderPlugin::AlignmentMuonRenderPlugin() {


}

bool AlignmentMuonRenderPlugin::applies( const DQMNet::CoreObject &o, const VisDQMImgInfo &i ) {
 
  if( (o.name.find( "Muon/DT" ) != std::string::npos ) ||
     (o.name.find( "Muon/CSC" ) != std::string::npos )) {
    return true;
  } 

  return false;

}

void AlignmentMuonRenderPlugin::preDraw( TCanvas *c, const DQMNet::CoreObject &o, const VisDQMImgInfo &i, VisDQMRenderInfo &r ) {

#ifdef DEBUG
  std::cout << "AlignmentMuonRenderPlugin:preDraw " << o.name << std::endl;
#endif

  if(o.object==NULL) return;
  
  
  c->cd();


  if( dynamic_cast<TH2F*>( o.object ) ) {
    preDrawTH2F( c, o );
  }
  else if( dynamic_cast<TH1F*>( o.object ) ) {
    preDrawTH1F( c, o );
  }

#ifdef DEBUG
  std::cout << "done" << std::endl;
#endif

}


void AlignmentMuonRenderPlugin::preDrawTH2F( TCanvas *c, const DQMNet::CoreObject &o ) {

  TH2F* obj = dynamic_cast<TH2F*>( o.object );
  assert( obj );

  // This applies to all
  gStyle->SetCanvasBorderMode(0);
  gStyle->SetPadBorderMode(0);
  gStyle->SetPadBorderSize(0);

  gStyle->SetOptStat(0);
  gStyle->SetPalette(1);

  obj->SetStats(kFALSE);
  obj->SetOption("colz");

  if(obj->GetEntries()!=0) c->SetLogz(0);
  c->SetGridx();
  //c->SetLeftMargin(0.15);
  //c->SetRightMargin(0.12);

  //gStyle->SetLabelSize(0.7);
  obj->GetXaxis()->SetLabelSize(0.03);
  obj->GetYaxis()->SetLabelSize(0.03);
  obj->GetXaxis()->SetNdivisions(15,true);
  obj->GetXaxis()->CenterLabels();


  if(o.name.find("CSC") != std::string::npos) {
  obj->GetXaxis()->SetLabelSize(0.02);
  obj->GetXaxis()->SetNdivisions(37,true);
  obj->GetYaxis()->SetLabelSize(0.03);

/*    obj->GetXaxis()->SetTitleOffset(1.15);
    c->SetBottomMargin(0.1);
    c->SetLeftMargin(0.15);
    c->SetRightMargin(0.12);*/
    return;
  }


  
  
}

void AlignmentMuonRenderPlugin::preDrawTH1F( TCanvas *c, const DQMNet::CoreObject &o ) {

  TH1* obj = dynamic_cast<TH1*>( o.object );

  assert( obj );

 if(obj->GetEntries() != 0 && 
 o.name.find("Rms") != std::string::npos) c->SetLogy(1);

  // This applies to all
  gStyle->SetCanvasBorderMode( 0 );
  gStyle->SetPadBorderMode( 0 );
  gStyle->SetPadBorderSize( 0 );
  gStyle->SetOptStat( 1111111 );
  obj->SetStats( kTRUE );
  //gStyle->SetLabelSize(0.04);
  obj->GetXaxis()->SetLabelSize(0.04);
  obj->GetYaxis()->SetLabelSize(0.04);

  return;

}

void AlignmentMuonRenderPlugin::postDraw( TCanvas *c, const DQMNet::CoreObject &o, const VisDQMImgInfo &i ) {

#ifdef DEBUG
  std::cout << "AlignmentMuonRenderPlugin:postDraw " << o.name << std::endl;
#endif

  c->cd();

  if( dynamic_cast<TH2F*>( o.object ) ) {
    postDrawTH2F( c, o );
  }
  else if( dynamic_cast<TH1F*>( o.object ) ) {
    postDrawTH1F( c, o );
  }


#ifdef DEBUG
  std::cout << "done" << std::endl;
#endif

}


void AlignmentMuonRenderPlugin::postDrawTH2F( TCanvas *c, const DQMNet::CoreObject &o ) {

  gPad->Update();
  TH2F * histo =  dynamic_cast<TH2F*>( o.object );
  TPaletteAxis *palette =(TPaletteAxis*)histo->GetListOfFunctions()->FindObject("palette");
  palette->SetLabelSize(0.02);
  palette->SetTitleOffset(0.5);

  return;

}

void AlignmentMuonRenderPlugin::postDrawTH1F( TCanvas *c, const DQMNet::CoreObject &o ) {

  TH1* obj = dynamic_cast<TH1*>( o.object );

  assert( obj );
  gStyle->SetOptStat( 1111111 );
  obj->SetStats( kTRUE );

  return;

}

