/*
 * =====================================================================================
 *
 *       Filename:  CSCRenderPlugin.h
 *
 *    Description:  CSC Histogram Rendering Plugin
 *
 *        Version:  1.0
 *        Created:  05/06/2008 03:50:48 PM
 *       Revision:  none
 *       Compiler:  gcc
 *
 *         Author:  Valdas Rapsevicius (VR), Valdas.Rapsevicius@cern.ch
 *        Company:  CERN, CH
 *
 * =====================================================================================
 */

#ifndef CSCRenderPlugin_H
#define CSCRenderPlugin_H

#include "VisMonitoring/DQMServer/interface/DQMRenderPlugin.h"
#include "VisMonitoring/DQMServer/interface/DQMRenderPluginDB.h"

#include "CSCRenderPlugin_ChamberMap.h"
#include "CSCRenderPlugin_SummaryMap.h"

#include <math.h>
#include <string>
#include <iostream>
#include <bitset>
#include <TH1.h>
#include <TH2.h>
#include <TBox.h>
#include <TText.h>
#include <TPRegexp.h>
#include <TStyle.h>
#include <TCanvas.h>

#define REREPLACE(pat, str, rep)       { TString s(str); TPRegexp(pat).Substitute(s, rep); str = s; }

typedef std::map<std::string, bool> MapOfPatternResults;

/**
 * @class CSCRenderPlugin
 * @brief Actual render plugin for CSCs
 */
class CSCRenderPlugin : public DQMRenderPlugin {
  public:
    virtual bool applies( const DQMNet::CoreObject &o, const VisDQMImgInfo &i );
    virtual void preDraw( TCanvas *c, const DQMNet::CoreObject &o, const VisDQMImgInfo &i, VisDQMRenderInfo&  r);
    virtual void postDraw( TCanvas *c, const DQMNet::CoreObject &o, const VisDQMImgInfo &i );
   private:
    const bool reMatch(const std::string pat, const std::string str);
    ChamberMap chamberMap;
    SummaryMap summaryMap;
    MapOfPatternResults mopr;
};


#endif
