#ifndef HCALRENDERPLUGIN_GUARD_H
# define HCALRENDERPLUGIN_GUARD_H


#define HCAL_ETAMIN -44.5
#define HCAL_ETAMAX 44.5
#define HCAL_PHIMIN -0.5
#define HCAL_PHIMAX 73.5

#include "VisMonitoring/DQMServer/interface/DQMRenderPlugin.h"
#include "VisMonitoring/DQMServer/interface/DQMRenderPluginDB.h" 

#include "TROOT.h"
#include "TH1.h"
#include "TH2.h"
#include "TStyle.h"
#include "TCanvas.h"
#include "TGaxis.h"
#include "TColor.h"
#include "TText.h"
#include "TLine.h"
#include "TPaletteAxis.h"
#include <cassert>
#include <fstream>

#include <iostream>
#include <string>

/*  HcalRenderPlugin.h code
 *  
 *  by Jeff Temple
 *  v1.0
 *  21 April 2008
 *
 *  Code shamelessly borrowed from existing SiStripRenderPlugin,
 *  EBRenderPlugin, etc.
 *
 *  Code will institute special Hcal-specific instructions for 
 *  drawing DQM histograms
 */

class HcalRenderPlugin: public DQMRenderPlugin
{
public:
  // inherits constructor, destructor from parent DQMRenderPlugin

  // These functions may be different that parent version
  virtual void		initialise (int argc, char **argv);
  virtual bool		applies (const DQMNet::CoreObject &o,
				 const VisDQMImgInfo &i);
  virtual void		preDraw (TCanvas *c,
				 const DQMNet::CoreObject &o,
				 const VisDQMImgInfo &i,
				 VisDQMRenderInfo &r);
  virtual void		postDraw (TCanvas *c,
				  const DQMNet::CoreObject &o,
				  const VisDQMImgInfo &i);

 private:
  
  void preDrawTH1 ( TCanvas *c, const DQMNet::CoreObject &o );
  void preDrawTH2 ( TCanvas *c, const DQMNet::CoreObject &o );
  void postDrawTH1( TCanvas *c, const DQMNet::CoreObject &o );
  void postDrawTH2( TCanvas *c, const DQMNet::CoreObject &o );
  void setErrorColor(void);
  void setRainbowColor(void);
  void drawEtaPhiLines(TH2* obj);
  // Color schemes
  int summaryColors[40];
  int errorFracColors[20];
  int standardColors[20];
};

#endif //  HCALRENDERPLUGIN_GUARD_H

